# Whatsappy

This is an open sourse package to interact with WhatsApp Business Cloud API using Python.

We are looking for colaborators.

# How to Install

```pip install whatsappy```

or in virtual env

```python -m pip install whatsappy```
